# flask-charts
Easily add google charts to templates

[![Build Status](https://travis-ci.com/albinmedoc/flask-charts.svg?token=4GyhcjtfvUszyhA5DD7J&branch=master)](https://travis-ci.com/albinmedoc/flask-charts)
[![codecov](https://codecov.io/gh/albinmedoc/flask-script/branch/master/graph/badge.svg)](https://codecov.io/gh/albinmedoc/flask-script)